@@ -1,5 +1,4 @@
 from .dane import DaneBenchmark  # noqa
-from .dane_no_misc import DaneNoMiscBenchmark  # noqa
 from .ddt_pos import DdtPosBenchmark  # noqa
 from .ddt_dep import DdtDepBenchmark  # noqa
 from .angry_tweets import AngryTweetsBenchmark  # noqa
@@ -15,3 +14,8 @@ from .ndt_nb_pos import NdtNBPosBenchmark  # noqa
 from .ndt_nn_pos import NdtNNPosBenchmark  # noqa
 from .ndt_nb_dep import NdtNBDepBenchmark  # noqa
 from .ndt_nn_dep import NdtNNDepBenchmark  # noqa
+from .dalaj import DalajBenchmark  # noqa
+from .absabank_imm import AbsabankImmBenchmark # noqa
+from .sdt_pos import SdtPosBenchmark  # noqa
+from .sdt_dep import SdtDepBenchmark  # noqa
+from .suc3 import Suc3Benchmark  # noqa
