@@ -52,6 +52,29 @@ def _get_dataset_from_url(url: str,
     return docs, labels
 
 
+def load_suc3() -> Tuple[dict, dict, dict, dict]:
+    '''Load the SUC 3.0 dataset.
+
+    Returns:
+        tuple:
+            Four dicts, `X_train`, `X_test`, `y_train` and `y_test`, where
+            `X_train` and `X_test` corresponds to the feature matrices for the
+            training and test split, respectively, and `y_train` and `y_test`
+            contains the target vectors.
+    '''
+    base_url = ('https://raw.githubusercontent.com/saattrupdan/ScandEval/'
+                'main/datasets/suc3/')
+    train_url = base_url + 'train.jsonl'
+    test_url = base_url + 'test.jsonl'
+    X_train, y_train = _get_dataset_from_url(train_url,
+                                             ['doc', 'tokens'],
+                                             'ner_tags')
+    X_test, y_test = _get_dataset_from_url(test_url,
+                                           ['doc', 'tokens'],
+                                           'ner_tags')
+    return X_train, X_test, y_train, y_test
+
+
 def load_norne_nb() -> Tuple[dict, dict, dict, dict]:
     '''Load the the Bokmål part of the NorNE dataset.
 
@@ -150,8 +173,8 @@ def load_angry_tweets() -> Tuple[dict, dict, dict, dict]:
                 'main/datasets/angry_tweets/')
     train_url = base_url + 'train.jsonl'
     test_url = base_url + 'test.jsonl'
-    X_train, y_train = _get_dataset_from_url(train_url, 'tweet', 'label')
-    X_test, y_test = _get_dataset_from_url(test_url, 'tweet', 'label')
+    X_train, y_train = _get_dataset_from_url(train_url, 'text', 'label')
+    X_test, y_test = _get_dataset_from_url(test_url, 'text', 'label')
     return X_train, X_test, y_train, y_test
 
 
@@ -178,29 +201,6 @@ def load_dane() -> Tuple[dict, dict, dict, dict]:
     return X_train, X_test, y_train, y_test
 
 
-def load_dane_no_misc() -> Tuple[dict, dict, dict, dict]:
-    '''Load the the DaNE dataset without MISC tags.
-
-    Returns:
-        tuple:
-            Four dicts, `X_train`, `X_test`, `y_train` and `y_test`, where
-            `X_train` and `X_test` corresponds to the feature matrices for the
-            training and test split, respectively, and `y_train` and `y_test`
-            contains the target vectors.
-    '''
-    base_url = ('https://raw.githubusercontent.com/saattrupdan/ScandEval/'
-                'main/datasets/dane_no_misc/')
-    train_url = base_url + 'train.jsonl'
-    test_url = base_url + 'test.jsonl'
-    X_train, y_train = _get_dataset_from_url(train_url,
-                                             ['doc', 'tokens'],
-                                             'ner_tags')
-    X_test, y_test = _get_dataset_from_url(test_url,
-                                           ['doc', 'tokens'],
-                                           'ner_tags')
-    return X_train, X_test, y_train, y_test
-
-
 def load_ndt_nb_pos() -> Tuple[dict, dict, dict, dict]:
     '''Load the Bokmål POS part of the NDT dataset.
 
@@ -353,8 +353,8 @@ def load_dkhate() -> Tuple[dict, dict, dict, dict]:
                 'main/datasets/dkhate/')
     train_url = base_url + 'train.jsonl'
     test_url = base_url + 'test.jsonl'
-    X_train, y_train = _get_dataset_from_url(train_url, 'tweet', 'label')
-    X_test, y_test = _get_dataset_from_url(test_url, 'tweet', 'label')
+    X_train, y_train = _get_dataset_from_url(train_url, 'text', 'label')
+    X_test, y_test = _get_dataset_from_url(test_url, 'text', 'label')
     return X_train, X_test, y_train, y_test
 
 
@@ -412,6 +412,90 @@ def load_twitter_sent() -> Tuple[dict, dict, dict, dict]:
                 'main/datasets/twitter_sent/')
     train_url = base_url + 'train.jsonl'
     test_url = base_url + 'test.jsonl'
-    X_train, y_train = _get_dataset_from_url(train_url, 'tweet', 'label')
-    X_test, y_test = _get_dataset_from_url(test_url, 'tweet', 'label')
+    X_train, y_train = _get_dataset_from_url(train_url, 'text', 'label')
+    X_test, y_test = _get_dataset_from_url(test_url, 'text', 'label')
+    return X_train, X_test, y_train, y_test
+
+
+def load_dalaj() -> Tuple[dict, dict, dict, dict]:
+    '''Load the DaLaJ dataset.
+
+    Returns:
+        tuple:
+            Four dicts, `X_train`, `X_test`, `y_train` and `y_test`, where
+            `X_train` and `X_test` corresponds to the feature matrices for the
+            training and test split, respectively, and `y_train` and `y_test`
+            contains the target vectors.
+    '''
+    base_url = ('https://raw.githubusercontent.com/saattrupdan/ScandEval/'
+                'main/datasets/dalaj/')
+    train_url = base_url + 'train.jsonl'
+    test_url = base_url + 'test.jsonl'
+    X_train, y_train = _get_dataset_from_url(train_url, 'text', 'label')
+    X_test, y_test = _get_dataset_from_url(test_url, 'text', 'label')
+    return X_train, X_test, y_train, y_test
+
+
+def load_absabank_imm() -> Tuple[dict, dict, dict, dict]:
+    '''Load the ABSAbank-Imm dataset.
+
+    Returns:
+        tuple:
+            Four dicts, `X_train`, `X_test`, `y_train` and `y_test`, where
+            `X_train` and `X_test` corresponds to the feature matrices for the
+            training and test split, respectively, and `y_train` and `y_test`
+            contains the target vectors.
+    '''
+    base_url = ('https://raw.githubusercontent.com/saattrupdan/ScandEval/'
+                'main/datasets/absabank_imm/')
+    train_url = base_url + 'train.jsonl'
+    test_url = base_url + 'test.jsonl'
+    X_train, y_train = _get_dataset_from_url(train_url, 'text', 'label')
+    X_test, y_test = _get_dataset_from_url(test_url, 'text', 'label')
+    return X_train, X_test, y_train, y_test
+
+
+def load_sdt_pos() -> Tuple[dict, dict, dict, dict]:
+    '''Load the POS part of the SDT dataset.
+
+    Returns:
+        tuple:
+            Four dicts, `X_train`, `X_test`, `y_train` and `y_test`, where
+            `X_train` and `X_test` corresponds to the feature matrices for the
+            training and test split, respectively, and `y_train` and `y_test`
+            contains the target vectors.
+    '''
+    base_url = ('https://raw.githubusercontent.com/saattrupdan/ScandEval/'
+                'main/datasets/sdt/')
+    train_url = base_url + 'train.jsonl'
+    test_url = base_url + 'test.jsonl'
+    X_train, y_train = _get_dataset_from_url(train_url,
+                                             ['doc', 'tokens'],
+                                             'pos_tags')
+    X_test, y_test = _get_dataset_from_url(test_url,
+                                           ['doc', 'tokens'],
+                                           'pos_tags')
+    return X_train, X_test, y_train, y_test
+
+
+def load_sdt_dep() -> Tuple[dict, dict, dict, dict]:
+    '''Load the dependency parsing part of the SDT dataset.
+
+    Returns:
+        tuple:
+            Four dicts, `X_train`, `X_test`, `y_train` and `y_test`, where
+            `X_train` and `X_test` corresponds to the feature matrices for the
+            training and test split, respectively, and `y_train` and `y_test`
+            contains the target vectors.
+    '''
+    base_url = ('https://raw.githubusercontent.com/saattrupdan/ScandEval/'
+                'main/datasets/sdt/')
+    train_url = base_url + 'train.jsonl'
+    test_url = base_url + 'test.jsonl'
+    X_train, y_train = _get_dataset_from_url(train_url,
+                                             ['doc', 'tokens'],
+                                             ['heads', 'deps'])
+    X_test, y_test = _get_dataset_from_url(test_url,
+                                           ['doc', 'tokens'],
+                                           ['heads', 'deps'])
     return X_train, X_test, y_train, y_test
