@@ -29,12 +29,9 @@ def get_all_datasets() -> list:
             entry the loading function.
     '''
     return [
-        ('dane', 'DaNE with MISC tags',
+        ('dane', 'DaNE',
             locate('scandeval.benchmarks.DaneBenchmark'),
             locate('scandeval.datasets.load_dane')),
-        ('dane-no-misc', 'DaNE without MISC tags',
-            locate('scandeval.benchmarks.DaneNoMiscBenchmark'),
-            locate('scandeval.datasets.load_dane_no_misc')),
         ('ddt-pos', 'the POS part of DDT',
             locate('scandeval.benchmarks.DdtPosBenchmark'),
             locate('scandeval.datasets.load_ddt_pos')),
@@ -80,6 +77,21 @@ def get_all_datasets() -> list:
         ('ndt-nn-dep', 'the Nynorsk DEP part of NDT',
             locate('scandeval.benchmarks.NdtNNDepBenchmark'),
             locate('scandeval.datasets.load_ndt_nn_dep')),
+        ('dalaj', 'DaLaJ',
+            locate('scandeval.benchmarks.DalajBenchmark'),
+            locate('scandeval.datasets.load_dalaj')),
+        ('absabank-imm', 'ABSAbank-Imm',
+            locate('scandeval.benchmarks.AbsabankImmBenchmark'),
+            locate('scandeval.datasets.load_absabank_imm')),
+        ('sdt-pos', 'the POS part of SDT',
+            locate('scandeval.benchmarks.SdtPosBenchmark'),
+            locate('scandeval.datasets.load_sdt_pos')),
+        ('sdt-dep', 'the DEP part of SDT',
+            locate('scandeval.benchmarks.SdtDepBenchmark'),
+            locate('scandeval.datasets.load_sdt_dep')),
+        ('suc3', 'SUC 3.0',
+            locate('scandeval.benchmarks.Suc3Benchmark'),
+            locate('scandeval.datasets.load_suc3')),
     ]
 
 
